@@ -1,20 +1,22 @@
 module DataMapper
   module Types
-    class ParanoidBoolean < DataMapper::Type(Boolean)
+    class ParanoidBoolean < Type
       primitive TrueClass
       default   false
       lazy      true
 
+      # TODO: document
+      # @api private
       def self.bind(property)
-        model = property.model
-        repository = property.repository
+        repository_name = property.repository_name
+        model           = property.model
+        property_name   = property.name
 
-        model.send(:set_paranoid_property, property.name){true}
-
-        model.class_eval <<-EOS, __FILE__, __LINE__
+        model.send(:set_paranoid_property, property_name){true}
 
+        model.class_eval <<-RUBY, __FILE__, __LINE__ + 1
           def self.with_deleted
-            with_exclusive_scope(#{property.name.inspect} => true) do
+            with_exclusive_scope(#{property_name.inspect} => true) do
               yield
             end
           end
@@ -25,9 +27,9 @@ module DataMapper
             end
             save
           end
-        EOS
+        RUBY
 
-        model.default_scope(repository.name).update(property.name => false)
+        model.default_scope(repository_name).update(property_name => false)
       end
     end # class ParanoidBoolean
   end # module Types
